@@ -4,7 +4,6 @@ from fief.schemas import (
     client,
     generics,
     permission,
-    reset,
     role,
     tenant,
     user,
@@ -22,7 +21,6 @@ __all__ = [
     "client",
     "generics",
     "permission",
-    "reset",
     "role",
     "tenant",
     "user",
